# Jyx

A simple text editor for developers in Python/Tkinter

## Summary

1. History
2. Features

## 1. History

Jyx is a simple text editor written in Python 3 using the Tkinter framework.

It started as a Java program around 2003-2004 before migrating to Python in 2017.

It was mainly to learn the amazing Tkinter framework, nice work folks!

I try to use it, fix its bugs, add new features from time to time.

Let me know if you find something weird!

## 2. Features

Not so much for now. No line numbers, no syntax highlighting.

Although it can execute directly Python script, even unsaved.

More to come...

## 3. Comparison with other editors

This table presents some common features of text editors.

|                     | Notepad | Gedit |  Jyx  |
|---------------------|:-------:|:-----:|:-----:|
| Syntax highlighting |    no   |  yes  |  yes  |
| Statistics          |    no   |  yes  |  yes  |

Damien Gouteux 2020-2021
